@@ -26,6 +26,9 @@ var listen = flag.String("l", ":9876", "监听地址")
 // 更新频率(秒)
 var every = flag.Int("f", 300, "同步间隔时间(秒)")
 
+// 缓存次数
+var ipCacheTimes = flag.Int("cacheTimes", 5, "间隔N次与服务商比对")
+
 // 服务管理
 var serviceType = flag.String("s", "", "服务管理, 支持install, uninstall")
 
@@ -66,6 +69,7 @@ func main() {
 	if *customDNSServer != "" {
 		os.Setenv(util.DNSServerEnv, *customDNSServer+":53")
 	}
+	os.Setenv(util.IPCacheTimesENV, strconv.Itoa(*ipCacheTimes))
 	switch *serviceType {
 	case "install":
 		installService()
